"""
web_admin urls file
"""
# django imports
from django.urls import path, include
from rest_framework import routers

# local imports
from web_admin.views.analytics import AnalyticsViewSet
from web_admin.views.article import (ArticleViewSet, DefaultArticleCardImagesViewSet, ArticleListViewSet,
                                     ArticleCardListViewSet)
from web_admin.views.auth import ForgotAndResetPasswordViewSet
from web_admin.views.user_management import UserManagementViewSet

# initiate router
router = routers.SimpleRouter()

router.register('article', ArticleViewSet, basename='article')
router.register('default-card-images', DefaultArticleCardImagesViewSet, basename='default-card-images')
router.register('user-management', UserManagementViewSet, basename='user')
router.register('analytics', AnalyticsViewSet, basename='analytics')

router.register('article-list', ArticleListViewSet, basename='article-list')
router.register('article-card-list', ArticleCardListViewSet, basename='article-card-list')

# forgot and reset password api for admin
router.register('admin', ForgotAndResetPasswordViewSet, basename='admin')

urlpatterns = [
    path('api/v1/', include(router.urls)),
]
